#include "mainwindow.h"
#include "addressmodel.h"

#include <QWebView>
#include <QWebFrame>
#include <QHeaderView>
#include <QtDebug>

MainWindow::MainWindow(QWidget *parent, Qt::WFlags flags)
    : QWidget(parent, flags)
{
    ui.setupUi(this);

    ui.treeView->setModel(new AddressModel(this));
    ui.treeView->header()->setStretchLastSection(true);

    connect(ui.treeView,SIGNAL(clicked(QModelIndex)),this,SLOT(showItem(QModelIndex)));
    connect(ui.pushButton,SIGNAL(clicked()),this,SLOT(moveCursor()));

    ui.map->load(QUrl("../index.html"));

    connect(ui.map->page()->mainFrame(), SIGNAL(javaScriptWindowObjectCleared()),
            this, SLOT(populateJavaScriptWindowObject()));
}

MainWindow::~MainWindow()
{
}

void MainWindow::populateJavaScriptWindowObject()
{
    ui.map->page()->mainFrame()->addToJavaScriptWindowObject("mainWindow", this);
}

void MainWindow::debugMessage(const QString& str)
{
    ui.textEdit->append(str);
}

void MainWindow::showItem(const QModelIndex &idx)
{
    ui.map->clearCoordinates();
    ui.map->geoCode( idx.data(Qt::DisplayRole).toString() );
}
void MainWindow::moveCursor()
{
    QPoint tmp = QCursor::pos();

    QCursor::setPos(ui.map->mapToGlobal(QPoint(10,10)));
    QApplication::processEvents();
    QCursor::setPos(ui.map->mapToGlobal(QPoint(ui.map->width()-20, ui.map->height()-20)));
    QApplication::processEvents();

    QCursor::setPos(tmp);
}

void MainWindow::onGeo(int lat, int lng)
{
    QString str = QString::number(lat) + " " + QString::number(lng);
    debugMessage(str);
}
